Welcome to pwman3’s documentation! — pwman3 0.6 documentation

# Welcome to pwman3’s documentation!

Contents:

- Installing and upgrading:
  - Upgrading from version 0.5.x
  - Upgrading from version 0.6 or later:
  - A Note about Python versions
  - Database versions
- Pwman3 - tutorial
- Configuring Pwman3
- Packaging for UNIX\Linux
  - Requirements and suggested packages
  - Building a man page

## About pwman3:

Pwman3 is a command line password manager for Python3 with support for multiple databases.